/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

qwi.dta - a cleaned version of the Quarterly Worforce Indicators, linked to State minimum wage data and other covariates

*/

*----------------------------*
*   JOB GROWTH BY INDUSTRY   *
*----------------------------*

clear all
set more off
set matsize 2000

* Define some shorter value labels for purposes of the Table
program newindlab
label define newindlab 10 "All"
label define newindlab 11 "11: Agriculture and wildlife" , add
label define newindlab 21 "21: Mining" , add
label define newindlab 22 "22: Utilities" , add
label define newindlab 23 "23: Construction" , add
label define newindlab 31 "31-33: Manufacturing" , add
label define newindlab 42 "42: Wholesale trade" , add
label define newindlab 44 "44-45: Retail trade" , add
label define newindlab 48 "48-49: Transportation and warehouse" , add
label define newindlab 51 "51: Information service" , add
label define newindlab 52 "52: Finance and insurance" , add
label define newindlab 53 "53: Real estate" , add
label define newindlab 54 "54: Professional service" , add
label define newindlab 55 "55: Management" , add
label define newindlab 56 "56: Administrative support" , add
label define newindlab 61 "61: Education related" , add
label define newindlab 62 "62: Health care" , add
label define newindlab 71 "71: Arts and entertainment" , add
label define newindlab 72 "72: Accommodation and food" , add
label define newindlab 81 "81: Other service" , add
label define newindlab 92 "92: Public administration" , add
label values industry newindlab
end

* QCEW

use qcew , clear
newindlab
keep if industry == 10 & quarterly >= 121 // Drops pre-1990 (pre-NAICS) data
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , fe robust cluster(state)
estimates store qcew_bit

#delimit ;
esttab qcew_bit using appendix_table_results_QCEW_industry_bit.csv 
, replace b(4) se(4) label coeflabels(lnmin "All") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide
;
#delimit cr

foreach industry in 11 21 22 23 31 42 44 48 51 52 53 54 55 56 61 62 71 72 81 92 {

estimates clear

use qcew , clear
newindlab
keep if industry == `industry' & quarterly >= 121 // Drops pre-1990 (pre-NAICS) data
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , fe robust cluster(state)
estimates store qcew_bit

#delimit ;
esttab qcew_bit using appendix_table_results_QCEW_industry_bit.csv 
, append b(4) se(4) label coeflabels(lnmin "`:label newindlab `industry''") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide noobs
;
#delimit cr

}

******


* QWI

use qwi , clear
newindlab
keep if industry == 10 & agegrp == 0
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store qwi_bit

#delimit ;
esttab qwi_bit using appendix_table_results_QWI_industry_bit.csv 
, replace b(4) se(4) label coeflabels(lnmin "All") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide
;
#delimit cr

foreach industry in 11 21 22 23 31 42 44 48 51 52 53 54 55 56 61 62 71 72 81 92 {

estimates clear

use qwi , clear
newindlab
keep if industry == `industry' & agegrp == 0
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store qwi_bit

#delimit ;
esttab qwi_bit using appendix_table_results_QWI_industry_bit.csv 
, append b(4) se(4) label coeflabels(lnmin "`:label newindlab `industry''") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide noobs
;
#delimit cr

}


*---------------------------------*
*   JOB GROWTH BY AGE GROUP       *
*---------------------------------*

clear all
set more off
set matsize 2000

use qwi , clear
keep if industry == 10 & agegrp == 0
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store qwi_bit

#delimit ;
esttab qwi_bit using appendix_table_results_QWI_age_bit.csv 
, replace b(4) se(4) label coeflabels(lnmin "`:label agelab 0'") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide
;
#delimit cr

forv age = 1/8 {

estimates clear

use qwi , clear
keep if industry == 10 & agegrp == `age'
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store qwi_bit

#delimit ;
esttab qwi_bit using appendix_table_results_QWI_age_bit.csv 
, append b(4) se(4) label coeflabels(lnmin "`:label agelab `age''") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide noobs
;
#delimit cr

}


*---------------------------------*
*   JOB GROWTH BY EDUCATION       *
*---------------------------------*

clear all
set more off
set matsize 2000

use qwi_educ , clear
keep if education == 0
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store qwi_bit

#delimit ;
esttab qwi_bit using appendix_table_results_QWI_educ_bit.csv 
, replace b(4) se(4) label coeflabels(lnmin "`:label educlab 0'") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide
;
#delimit cr

forv educ = 1/4 {

estimates clear

use qwi_educ , clear
keep if education == `educ'
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store qwi_bit

#delimit ;
esttab qwi_bit using appendix_table_results_QWI_educ_bit.csv 
, append b(4) se(4) label coeflabels(lnmin "`:label educb `educ''") nomtitles title( ) 
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin) nonotes nogap nonum wide noobs
;
#delimit cr

}

