/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html
                 xtabond2 - - available from within Stata by typing "ssc install xtabond2" 
		 (Note: the xtabond2 command as we use it may not function properly on versions of Stata older than Stata 13)

Files needed: 

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

qwi.dta - a cleaned version of the Quarterly Worforce Indicators, linked to State minimum wage data and other covariates

*/

clear all
set more off
set matsize 4000

* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership
gen tempmw = lnmin if year == 1975 & quarter == 1
egen initmw = min(tempmw) , by(statefips)
drop tempmw

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settingss

*******

estimates clear

*******

* Without jurisdiction-specific time trends:

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
estimates store col1

qui xtreg lemp L(0/15).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
estimates store col2

qui lincomest L0.lnmin + L.lnmin + L2.lnmin + L3.lnmin + L4.lnmin + L5.lnmin + L6.lnmin + L7.lnmin + L8.lnmin + ///
L9.lnmin + L10.lnmin + L11.lnmin + L12.lnmin + L13.lnmin + L14.lnmin + L15.lnmin
estimates store lincom2

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3

qui xtabond2 lemp L.lemp L(0/3).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , gmm(lnmin) iv(L.lemp i.quarterly#i.censusreg lpopall share1559 lrgspcap) nolevel robust
estimates store col4

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col5

* With jurisdiction-specific time trends:

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store col1b

qui xtreg lemp L(0/15).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store col2b

qui lincomest L0.lnmin + L.lnmin + L2.lnmin + L3.lnmin + L4.lnmin + L5.lnmin + L6.lnmin + L7.lnmin + L8.lnmin + ///
L9.lnmin + L10.lnmin + L11.lnmin + L12.lnmin + L13.lnmin + L14.lnmin + L15.lnmin
estimates store lincom2b

qui xtreg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , fe robust cluster(state)
estimates store col3b

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3b

qui xtabond2 lemp L.lemp L(0/3).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly , gmm(lnmin) iv(L.lemp i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly) nolevel robust
estimates store col4b

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , fe robust cluster(state)
estimates store col5b

*******

gen temp1 = 1
gen temp2 = 1
qui reg temp1 temp2
estimates store lincomfill

#delimit ;
esttab col1 col2 col3 col4 col5 using appendix_table_results_QCEW_notrend.csv ,
replace b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin L.lemp L*.lnmin L.lnmin D.lnmin) nonotes nogap
coeflabels(
L.lemp "1st lag of log-emp."
lnmin "Log-MW"
L.lnmin         "1st lag of log-MW"
L2.lnmin        "2nd lag of log-MW"
L3.lnmin        "3rd lag of log-MW"
L4.lnmin	"4th lag of log-MW"
L5.lnmin	"5th lag of log-MW"
L6.lnmin	"6th lag of log-MW"
L7.lnmin	"7th lag of log-MW"
L8.lnmin	"8th lag of log-MW"
L9.lnmin	"9th lag of log-MW"
L10.lnmin	"10th lag of log-MW"
L11.lnmin	"11th lag of log-MW"
L12.lnmin	"12th lag of log-MW"
L13.lnmin	"13th lag of log-MW"
L14.lnmin	"14th lag of log-MW"
L15.lnmin	"15th lag of log-MW"
D.lnmin         "Log-MW"
LD.lnmin        "1st lag of log-MW"
L2D.lnmin       "2nd lag of log-MW"
L3D.lnmin       "3rd lag of log-MW"
L4D.lnmin	"4th lag of log-MW"
L5D.lnmin	"5th lag of log-MW"
L6D.lnmin	"6th lag of log-MW"
L7D.lnmin	"7th lag of log-MW"
L8D.lnmin	"8th lag of log-MW"
L9D.lnmin	"9th lag of log-MW"
L10D.lnmin	"10th lag of log-MW"
L11D.lnmin	"11th lag of log-MW"
L12D.lnmin	"12th lag of log-MW"
L13D.lnmin	"13th lag of log-MW"
L14D.lnmin	"14th lag of log-MW"
L15D.lnmin	"15th lag of log-MW"
) mtitles( ) ;
#delimit cr

#delimit ;
esttab lincomfill lincom2 lincom3 using appendix_table_results_QCEW_notrend.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) nonotes nogap noobs nomtitles nonum nocons
;
#delimit cr

#delimit ;
esttab col1b col2b col3b col4b col5b using appendix_table_results_QCEW_trend.csv ,
replace b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin L.lemp L*.lnmin L.lnmin D.lnmin) nonotes nogap
coeflabels(
L.lemp "1st lag of log-emp."
lnmin "Log-MW"
L.lnmin         "1st lag of log-MW"
L2.lnmin        "2nd lag of log-MW"
L3.lnmin        "3rd lag of log-MW"
L4.lnmin	"4th lag of log-MW"
L5.lnmin	"5th lag of log-MW"
L6.lnmin	"6th lag of log-MW"
L7.lnmin	"7th lag of log-MW"
L8.lnmin	"8th lag of log-MW"
L9.lnmin	"9th lag of log-MW"
L10.lnmin	"10th lag of log-MW"
L11.lnmin	"11th lag of log-MW"
L12.lnmin	"12th lag of log-MW"
L13.lnmin	"13th lag of log-MW"
L14.lnmin	"14th lag of log-MW"
L15.lnmin	"15th lag of log-MW"
D.lnmin         "Log-MW"
LD.lnmin        "1st lag of log-MW"
L2D.lnmin       "2nd lag of log-MW"
L3D.lnmin       "3rd lag of log-MW"
L4D.lnmin	"4th lag of log-MW"
L5D.lnmin	"5th lag of log-MW"
L6D.lnmin	"6th lag of log-MW"
L7D.lnmin	"7th lag of log-MW"
L8D.lnmin	"8th lag of log-MW"
L9D.lnmin	"9th lag of log-MW"
L10D.lnmin	"10th lag of log-MW"
L11D.lnmin	"11th lag of log-MW"
L12D.lnmin	"12th lag of log-MW"
L13D.lnmin	"13th lag of log-MW"
L14D.lnmin	"14th lag of log-MW"
L15D.lnmin	"15th lag of log-MW"
) mtitles( ) ;
#delimit cr

#delimit ;
esttab lincomfill lincom2b lincom3b using appendix_table_results_QCEW_trend.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) nonotes nogap noobs nomtitles nonum nocons
;
#delimit cr


****************************

* QWI:

use qcew , clear
keep if year == 1990 & quarter == 1
keep state lnmin
rename lnmin initmw
duplicates drop
merge 1:m state using qwi
drop if _merge == 1
drop _merge
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

*******

estimates clear

*******

* Without jurisdiction-specific time trends:

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
estimates store col1

qui xtreg lemp L(0/15).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
estimates store col2

qui lincomest L0.lnmin + L.lnmin + L2.lnmin + L3.lnmin + L4.lnmin + L5.lnmin + L6.lnmin + L7.lnmin + L8.lnmin + ///
L9.lnmin + L10.lnmin + L11.lnmin + L12.lnmin + L13.lnmin + L14.lnmin + L15.lnmin
estimates store lincom2

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3

qui xtabond2 lemp L.lemp L(0/3).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap , gmm(lnmin) iv(L.lemp i.quarterly#i.censusreg lpopall share1559 lrgspcap) nolevel robust
estimates store col4

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col5

* With jurisdiction-specific time trends:

qui xtreg lemp lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store col1b

qui xtreg lemp L(0/15).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store col2b

qui lincomest L0.lnmin + L.lnmin + L2.lnmin + L3.lnmin + L4.lnmin + L5.lnmin + L6.lnmin + L7.lnmin + L8.lnmin + ///
L9.lnmin + L10.lnmin + L11.lnmin + L12.lnmin + L13.lnmin + L14.lnmin + L15.lnmin
estimates store lincom2b

qui xtreg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store col3b

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3b

qui xtabond2 lemp L.lemp L(0/3).lnmin i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly , gmm(lnmin) iv(L.lemp i.quarterly#i.censusreg lpopall share1559 lrgspcap i.state#c.quarterly) nolevel robust
estimates store col4b

qui xtreg D.lemp lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap i.state#c.quarterly , fe robust cluster(state)
estimates store col5b

*******

gen temp1 = 1
gen temp2 = 1
qui reg temp1 temp2
estimates store lincomfill

#delimit ;
esttab col1 col2 col3 col4 col5 using appendix_table_results_QWI_notrend.csv ,
replace b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin L.lemp L*.lnmin L.lnmin D.lnmin) nonotes nogap
coeflabels(
L.lemp "1st lag of log-emp."
lnmin "Log-MW"
L.lnmin         "1st lag of log-MW"
L2.lnmin        "2nd lag of log-MW"
L3.lnmin        "3rd lag of log-MW"
L4.lnmin	"4th lag of log-MW"
L5.lnmin	"5th lag of log-MW"
L6.lnmin	"6th lag of log-MW"
L7.lnmin	"7th lag of log-MW"
L8.lnmin	"8th lag of log-MW"
L9.lnmin	"9th lag of log-MW"
L10.lnmin	"10th lag of log-MW"
L11.lnmin	"11th lag of log-MW"
L12.lnmin	"12th lag of log-MW"
L13.lnmin	"13th lag of log-MW"
L14.lnmin	"14th lag of log-MW"
L15.lnmin	"15th lag of log-MW"
D.lnmin         "Log-MW"
LD.lnmin        "1st lag of log-MW"
L2D.lnmin       "2nd lag of log-MW"
L3D.lnmin       "3rd lag of log-MW"
L4D.lnmin	"4th lag of log-MW"
L5D.lnmin	"5th lag of log-MW"
L6D.lnmin	"6th lag of log-MW"
L7D.lnmin	"7th lag of log-MW"
L8D.lnmin	"8th lag of log-MW"
L9D.lnmin	"9th lag of log-MW"
L10D.lnmin	"10th lag of log-MW"
L11D.lnmin	"11th lag of log-MW"
L12D.lnmin	"12th lag of log-MW"
L13D.lnmin	"13th lag of log-MW"
L14D.lnmin	"14th lag of log-MW"
L15D.lnmin	"15th lag of log-MW"
) mtitles( ) ;
#delimit cr

#delimit ;
esttab lincomfill lincom2 lincom3 using appendix_table_results_QWI_notrend.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) nonotes nogap noobs nomtitles nonum nocons
;
#delimit cr

#delimit ;
esttab col1b col2b col3b col4b col5b using appendix_table_results_QWI_trend.csv ,
replace b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) keep(lnmin L.lemp L*.lnmin L.lnmin D.lnmin) nonotes nogap
coeflabels(
L.lemp "1st lag of log-emp."
lnmin "Log-MW"
L.lnmin         "1st lag of log-MW"
L2.lnmin        "2nd lag of log-MW"
L3.lnmin        "3rd lag of log-MW"
L4.lnmin	"4th lag of log-MW"
L5.lnmin	"5th lag of log-MW"
L6.lnmin	"6th lag of log-MW"
L7.lnmin	"7th lag of log-MW"
L8.lnmin	"8th lag of log-MW"
L9.lnmin	"9th lag of log-MW"
L10.lnmin	"10th lag of log-MW"
L11.lnmin	"11th lag of log-MW"
L12.lnmin	"12th lag of log-MW"
L13.lnmin	"13th lag of log-MW"
L14.lnmin	"14th lag of log-MW"
L15.lnmin	"15th lag of log-MW"
D.lnmin         "Log-MW"
LD.lnmin        "1st lag of log-MW"
L2D.lnmin       "2nd lag of log-MW"
L3D.lnmin       "3rd lag of log-MW"
L4D.lnmin	"4th lag of log-MW"
L5D.lnmin	"5th lag of log-MW"
L6D.lnmin	"6th lag of log-MW"
L7D.lnmin	"7th lag of log-MW"
L8D.lnmin	"8th lag of log-MW"
L9D.lnmin	"9th lag of log-MW"
L10D.lnmin	"10th lag of log-MW"
L11D.lnmin	"11th lag of log-MW"
L12D.lnmin	"12th lag of log-MW"
L13D.lnmin	"13th lag of log-MW"
L14D.lnmin	"14th lag of log-MW"
L15D.lnmin	"15th lag of log-MW"
) mtitles( ) ;
#delimit cr

#delimit ;
esttab lincomfill lincom2b lincom3b using appendix_table_results_QWI_trend.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) nonotes nogap noobs nomtitles nonum nocons
;
#delimit cr
