/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

qwi.dta - a cleaned version of the Quarterly Worforce Indicators, linked to State minimum wage data and other covariates

*/

*----------------------*
*   ROBUSTNESS CHECKS  *
*----------------------*

* Dist. Lag of First-differences model
* 1. Reproduce baseline result (no trends) from main results
* Falsification Tests:
* 2. 1-period lead of ln(MW)
* 3. 2-period lead of ln(MW)
* 4. Both 1-2 period leads of ln(MW)
* 5. Census Division by Time Fixed Effects
* 6. Quadratic Jurisdiction-specific time trends
* 7. Drop observations that used minimum wage inflation indexing
* 8. Drop 2008-2010 Financial Crisis years

* Break-in-Trend model
* 1. Reproduce baseline result (with trends) from main results
* Falsification Tests:
* 2. I(next period change in MW)
* 3. 2-period lead of ln(MW)
* 4. 3-period lead of ln(MW)
* 5. Census Division by Time Fixed Effects
* 6. Quadratic Jurisdiction-specific time trends
* 7. Drop observations that used minimum wage inflation indexing

clear all
set more off
set matsize 4000

**********

*  Results for distributed lags (first difference of employment)

* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

estimates clear

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col1

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom1

qui reg D.lemp DL(0/15).lnmin DF.lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col2

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom2

qui reg D.lemp DL(0/15).lnmin DF2.lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3

qui reg D.lemp DL(0/15).lnmin DF(1/2).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col4

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom4

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusdiv D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col5

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom5

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap if indexedwage == 0 , robust cluster(state)
estimates store col6

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom6

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap if year < 2008 , robust cluster(state)
estimates store col7

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom7

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7
using appendix_table_robustness_QCEW_DLFD.csv , replace b(4) se(3) label
keep(D.lnmin L*.lnmin F*.lnmin)
title( ) star(* 0.1 ** 0.05 *** 0.01)
nonotes nogap mtitles("Baseline results" 
"Leading values" "Leading values" "Leading values"
"Division by time"
"Inflation indexing" "Financial crisis")
;
#delimit cr

#delimit ;
esttab lincom1 lincom2 lincom3 lincom4 lincom5 lincom6 lincom7 using appendix_table_robustness_QCEW_DLFD.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) nonotes nogap noobs nomtitles nonum nocons
;
#delimit cr


* QWI

use qwi , clear
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

*******

estimates clear

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col1

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom1

qui reg D.lemp DL(0/15).lnmin DF.lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col2

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom2

qui reg D.lemp DL(0/15).lnmin DF2.lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom3

qui reg D.lemp DL(0/15).lnmin DF(1/2).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col4

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom4

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusdiv D4.lpopall D4.share1559 D4.lrgspcap , robust cluster(state)
estimates store col5

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom5

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap if indexedwage == 0 , robust cluster(state)
estimates store col6

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom6

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap if year < 2008 , robust cluster(state)
estimates store col7

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin
estimates store lincom7

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7
using appendix_table_robustness_QWI_DLFD.csv , append b(4) se(3) label
keep(D.lnmin L*.lnmin F*.lnmin)
title( ) star(* 0.1 ** 0.05 *** 0.01)
nonotes nogap mtitles("Baseline results" 
"Leading values" "Leading values" "Leading values"
"Division by time"
"Inflation indexing" "Financial crisis")
;
#delimit cr

#delimit ;
esttab lincom1 lincom2 lincom3 lincom4 lincom5 lincom6 lincom7 using appendix_table_robustness_QWI_DLFD.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) nonotes nogap noobs nomtitles nonum nocons
;
#delimit cr


**********

*  Results for break in trend model

* QCEW

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership
gen tempmw = lnmin if year == 1975 & quarter == 1
egen initmw = min(tempmw) , by(statefips)
drop tempmw
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

gen delta_next = (f.mw > mw)
replace delta_next = . if f.mw == .

gen quarterly_sq = quarterly^2

*******

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col1

qui reg D.lemp lnmin initmw delta_next i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col2

qui reg D.lemp lnmin initmw f2.lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col3

qui reg D.lemp lnmin initmw f3.lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col4

qui reg D.lemp lnmin initmw i.quarterly#i.censusdiv D4.lpopall D4.share1559 D4.lrgspcap ,  robust cluster(state)
estimates store col5

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  if indexedwage == 0 ,  robust cluster(state)
estimates store col6

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  if year < 2008 ,  robust cluster(state)
estimates store col7

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7
using appendix_table_robustness_QCEW_BiT.csv , replace b(4) se(3) label
coeflabels(lnmin "QCEW: FD in Log(emp) // Log of minimum wage"
delta_next "I(Delta MW t+1)" F2.lnmin "Log of MW t+2" 
F3.lnmin "Log of MW t+3")
title( ) star(* 0.1 ** 0.05 *** 0.01) keep(lnmin delta_next F2.lnmin F3.lnmin) 
nonotes nogap mtitles("Baseline results" 
"Leading values" "Leading values" "Leading values"
"Division by time" 
"Inflation indexing" "Financial crisis")
;
#delimit cr


* QWI

clear all
set more off

use qcew , clear
keep if year == 1990 & quarter == 1
keep state lnmin
rename lnmin initmw
duplicates drop
merge 1:m state using qwi
drop if _merge == 1
drop _merge
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

gen delta_next = (f.mw > mw)
replace delta_next = . if f.mw == .

gen quarterly_sq = quarterly^2

*******

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col1

qui reg D.lemp lnmin initmw delta_next i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col2

qui reg D.lemp lnmin initmw f2.lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col3

qui reg D.lemp lnmin initmw f3.lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  ,  robust cluster(state)
estimates store col4

qui reg D.lemp lnmin initmw i.quarterly#i.censusdiv D4.lpopall D4.share1559 D4.lrgspcap ,  robust cluster(state)
estimates store col5

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  if indexedwage == 0 ,  robust cluster(state)
estimates store col6

qui reg D.lemp lnmin initmw i.quarterly#i.censusreg D4.lpopall D4.share1559 D4.lrgspcap  if year < 2008 ,  robust cluster(state)
estimates store col7

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7 
using appendix_table_robustness_QWI_BiT.csv , replace b(4) se(3) label
coeflabels(lnmin "QWI: FD in Log(emp) // Log of minimum wage"
delta_next "I(Delta MW t+1)" F2.lnmin "Log of MW t+2" 
F3.lnmin "Log of MW t+3")
title( ) star(* 0.1 ** 0.05 *** 0.01) keep(lnmin delta_next F2.lnmin F3.lnmin) 
nonotes nogap mtitles("Baseline results" 
"Leading values" "Leading values" "Leading values"
"Division by time" 
"Inflation indexing" "Financial crisis")
;
#delimit cr
