/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html
                 xtabond2 - - available from within Stata by typing "ssc install xtabond2" 
		 (Note: the xtabond2 command as we use it may not function properly on versions of Stata older than Stata 13)
	      
Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

*/

*--------------------*
*    MAIN RESULTS    *
*--------------------*

clear all
set more off

* BDS:

use bds , clear
gen tempmw = lnmin if year == 1977
egen initmw = min(tempmw) , by(statefips)
drop tempmw

fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 year // Setting some technical factor-variable settings

*******

* Without jurisdiction-specific time trends:

qui xtreg lemp lnmin i.year#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
estimates store col1

qui xtreg lemp L(0/3).lnmin i.year#i.censusreg lpopall share1559 lrgspcap , fe robust cluster(state)
estimates store col2

lincom lnmin + L1.lnmin + L2.lnmin + L3.lnmin

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col3

lincom D1.lnmin + LD.lnmin + L2D.lnmin + L3D.lnmin

qui xtabond2 lemp L.lemp L(0/1).lnmin i.year#i.censusreg lpopall share1559 lrgspcap, gmm(lnmin) iv(L.lemp i.year#i.censusreg  lpopall share1559 lrgspcap) nolevel robust
estimates store col4

qui reg D.lemp lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col5

* With jurisdiction-specific time trends:

qui xtreg lemp lnmin i.year#i.censusreg lpopall share1559 lrgspcap i.state#c.year , fe robust cluster(state)
estimates store col1b

qui xtreg lemp L(0/3).lnmin i.year#i.censusreg lpopall share1559 lrgspcap i.state#c.year , fe robust cluster(state)
estimates store col2b

lincom lnmin + L1.lnmin + L2.lnmin + L3.lnmin

qui xtreg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , fe robust cluster(state)
estimates store col3b

lincom D1.lnmin + LD.lnmin + L2D.lnmin + L3D.lnmin

qui xtabond2 lemp L.lemp L(0/1).lnmin i.year#i.censusreg lpopall share1559 lrgspcap i.state#c.year, gmm(lnmin) iv(L.lemp i.year#i.censusreg i.state#c.year lpopall share1559 lrgspcap) nolevel robust
estimates store col4b

qui xtreg D.lemp lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , fe robust cluster(state)
estimates store col5b

*******

#delimit ;
esttab col1 col2 col3 col4 col5  using table_results_BDS.csv ,
replace b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) keep(L.lemp lnmin D.lnmin L*.lnmin) nonotes nogap noobs
coeflabels(
L.lemp "1st lag of log-employment" lnmin "Log-MW" 
L.lnmin "1st lag of log-MW" LD.lnmin "1st lag of log-MW" 
L2.lnmin "2nd lag of log-MW" L2D.lnmin "2nd lag of log-MW"
L3.lnmin "3rd lag of log-MW" L3D.lnmin "3rd lag of log-MW" 
D.lnmin "Log-MW"
)
mtitles(
) ;

#delimit ;
esttab col1b col2b col3b col4b col5b using table_results_BDS.csv ,
append b(4) se(4) label title( )
star(* 0.1 ** 0.05 *** 0.01) keep(L.lemp lnmin D.lnmin L*.lnmin) nonotes nogap nomtitles nonumbers
coeflabels(
L.lemp "1st lag of log-employment" lnmin "Log-MW" 
L.lnmin "1st lag of log-MW" LD.lnmin "1st lag of log-MW" 
L2.lnmin "2nd lag of log-MW" L2D.lnmin "2nd lag of log-MW"
L3.lnmin "3rd lag of log-MW" L3D.lnmin "3rd lag of log-MW" 
D.lnmin "Log-MW"
) ;
#delimit cr
