/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

*/

*--------------------*
* SUMMARY STATISTICS *
*--------------------*

clear all
set more off

* BDS:

use bds , clear

gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jc jd jg popall {
replace `var'=`var'/1000
}

quietly estpost summarize mw realmw emp jg jgl jc jd popall share1559 rgspcap , detail
eststo sumstats_bds

#delimit ;
esttab sumstats_bds using table_sumstats_BDS.csv , replace 
cells(`"mean(fmt(a2)) sd(fmt(a3)) p50(fmt(a2))"') 
label collabels("Mean" "Std. Dev." "Median") 
coeflabels(mw "State minimum wage (\$)" realmw "State minimum wage (\$real)" 
jg "Job growth (thousands)" jgl "Job growth (log)" emp "Jobs (thousands)" 
jc "Job creation (thousands)" jd "Job destruction (thousands)" 
popall "Population (thousands)" share1559 "Share aged 15-59" rgspcap "GSP/capita (\$real)") 
nomtitles nonum
;
#delimit cr
